@@ -3,7 +3,7 @@ from enum import Enum
 from typing import MutableMapping
 
 from eth_typing import URI
-from web3 import HTTPProvider, IPCProvider, WebsocketProvider
+from web3 import HTTPProvider, IPCProvider
 from web3.providers.auto import load_provider_from_uri
 
 logger = logging.getLogger("web3provider")
@@ -11,7 +11,6 @@ logger = logging.getLogger("web3provider")
 
 class ProviderType(Enum):
     HTTP = "http"
-    WEBSOCKET = "websocket"
     IPC = "ipc"
 
 
@@ -32,14 +31,6 @@ def create_provider_from_config(rpc_config: MutableMapping):
         )
         logger.info("Using HTTP provider with URL {}".format(url))
         return HTTPProvider(URI(url))
-    elif provider_type is ProviderType.WEBSOCKET:
-        url = "{}://{}:{}".format(
-            "wss" if rpc_config["use_ssl"] else "ws",
-            rpc_config["host"],
-            rpc_config["port"],
-        )
-        logger.info("Using websocket provider with URL {}".format(url))
-        return WebsocketProvider(URI(url))
     elif provider_type is ProviderType.IPC:
         file_path = rpc_config["file_path"]
         logger.info("Using IPC provider with file path {}".format(file_path))
